@@ -66,6 +66,16 @@ def preprocess( ) :
     checkup_workspacedir( )
 
 
+def update_endpointkey( endpointkey ) :
+    set_key( "endpoint/key" , endpointkey )
+    del_key_alt( "endpoint/url" )
+    unpack_key( )
+    handle_sslverify_fornumericip( )
+
+def update_endpointkey_fromenv( ev ) :
+    update_endpointkey( s_util.environ_get( ev ) )
+
+
 def get_key( config_key , default_val = None ) :
 
     #    config[ "/config/init/path" ] = config_path
