@@ -395,8 +395,11 @@ def environ_getall( ) :
 
 def environ_get( k ) :
     if k in os.environ :
-        return( os.environ[k])
-    return(None)
+        return( os.environ[ k ] )
+    return( None )
+
+def environ_set( k , v ) :
+    os.environ[ k ] = v
 
 def container_appenvstatic_get( ) :
     ENV_STATIC = { }
@@ -491,3 +494,4 @@ def thread_get_id( ) :
 
 def glob_files( dp ) :
     return( glob.glob( dp ) )
+
