@@ -138,21 +138,21 @@ def server( runner , debug_errorprexit = False ) :
 
 
 
-
-runner_ctime = 0
+#####################################################################################################
+runner_omnibus_ctime = 0
 # Required to make module name scope available in function for importlib
 _sapi_runner_omnibus = None
-def sapirunner_reloadifchanged( path_runner ) :
-    global runner_ctime
+def sapirunner_omnibus_reloadifchanged( path_runner ) :
+    global runner_omnibus_ctime
     try :
-        if( s_util.file_changed( path_runner , runner_ctime ) ) :
-            runner_ctime = s_util.file_ctime( path_runner )
+        if( s_util.file_changed( path_runner , runner_omnibus_ctime ) ) :
+            runner_omnibus_ctime = s_util.file_ctime( path_runner )
             importlib.reload( _sapi_runner_omnibus )
             s_log.write( "path_runner RELOAD" , consoleprint = True )
             s_util.sleep( 3 )
 
     except Exception as e :
-        s_log.write( "ERROR sapirunner_reloadifchanged " + str( e ) , consoleprint = True )
+        s_log.write( "ERROR sapirunner_omnibus_reloadifchanged " + str( e ) , consoleprint = True )
         s_util.sleep( 3 )
         return( False )
 
@@ -172,8 +172,8 @@ def runner_omnibus( path_runner ) :
 
     import _sapi_runner_omnibus
 
-    global runner_ctime
-    runner_ctime = s_util.file_ctime( path_runner )
+    global runner_omnibus_ctime
+    runner_omnibus_ctime = s_util.file_ctime( path_runner )
 
     while True :
 
@@ -182,7 +182,7 @@ def runner_omnibus( path_runner ) :
         heartbeat( )
 
         #####################################################
-        if( not sapirunner_reloadifchanged( path_runner ) ) : continue
+        if( not sapirunner_omnibus_reloadifchanged( path_runner ) ) : continue
         #####################################################
 
         try :
@@ -204,7 +204,7 @@ def runner_omnibus( path_runner ) :
         #####################################################
 
         runner_exitcode = _sapi_runner_omnibus._entrypoint( )
-        s_log.write( "runner_exitcode " + str(runner_exitcode) , consoleprint = True )
+        s_log.write( "runner_exitcode " + str( runner_exitcode ) , consoleprint = True )
 
         #####################################################
 
@@ -215,6 +215,71 @@ def runner_omnibus( path_runner ) :
 
         s_log.write( "OK" )
 
+#####################################################################################################
+runner_internal_ctime = 0
+# Required to make module name scope available in function for importlib
+_sapi_runner_internal = None
+def sapirunner_internal_reloadifchanged( path_runner ) :
+    global runner_internal_ctime
+    try :
+        if( s_util.file_changed( path_runner , runner_internal_ctime ) ) :
+            runner_internal_ctime = s_util.file_ctime( path_runner )
+            importlib.reload( _sapi_runner_internal )
+            s_log.write( "path_runner RELOAD" , consoleprint = True )
+            s_util.sleep( 3 )
+
+    except Exception as e :
+        s_log.write( "ERROR sapirunner_internal_reloadifchanged " + str( e ) , consoleprint = True )
+        s_util.sleep( 3 )
+        return( False )
+
+    return( True )
+
+
+def runner_internal( path_runner ) :
+
+    # Required to make module name scope available in function for importlib
+    global _sapi_runner_internal
+
+    s_log.write( "RUNNER_internal START " + path_runner )
+
+    if( not s_util.sys_path_append_fp( path_runner ) ) :
+        s_log.write( "ERROR NOT FOUND " + path_runner , consoleprint = True )
+        prexit( "ERR" )
+
+    import _sapi_runner_internal
+
+    global runner_internal_ctime
+    runner_internal_ctime = s_util.file_ctime( path_runner )
+
+    while True :
+
+        s_util.sleep( 0.1 )
+
+        heartbeat( )
+
+        #####################################################
+        if( not sapirunner_internal_reloadifchanged( path_runner ) ) : continue
+        #####################################################
+
+        try :
+            runner_exitcode = _sapi_runner_internal._entrypoint( )
+            if( runner_exitcode > 0 ) :
+                s_log.write( "ERROR _sapi_runner_internal runner_exitcode " + str( runner_exitcode ) , consoleprint = True )
+                continue
+        except Exception as e :
+            s_log.write( "ERROR _sapi_runner_internal Exception " + str( e ) , consoleprint = True )
+            s_util.sleep( 3 )
+            continue
+
+        #####################################################
+
+def omnibus_ping( ) :
+    run( {
+        "_tests_omnibus_ping" : "y"
+    } )
+    return( s_db.meta_read( "_job_state" ) == "done" ) 
+
 #####################################################################
 
 # DATA
